<?php
namespace PrestaShop\Module\LCVPrestaConnector;

use Exception;
use LCVPrestaConnector;

/**
 * Configuration du module
 */
class Syncer
{
    /**
     * Module
     */
    private LCVPrestaConnector $module;

    /**
     * Pont vers le backoffice
     */
    private BridgeAdapter $bridge;


    /**
     * Instanciation
     */
    public function __construct(LCVPrestaConnector $module)
    {
        $this->module = $module;
        $this->bridge = $module->getBridge();
    }

    /**
     * Synchronise les données
     */
    public function sync()
    {
        // on regarde sur la base de données si nous avons un traitement déjà en cours
        $db = \Db::getInstance();

        // on va passer par un verrou pour éviter de lancer plusieurs fois le traitement
        // le nom du verrou est composé du nom du module et du nom de domaine du site
        $lockName = 'syncer-' . $this->module->name . '-' . str_replace('.', '_', $_SERVER['HTTP_HOST']);

        // on tente de prendre le verrou
        if (!$db->execute('SELECT GET_LOCK(\'' . $lockName . '\', 0)')) {
            // le verrou est déjà pris, on ne fait rien
            echo "Traitement déjà en cours !";
            return;
        }

        try
        {
            // Etape 1 : on se connecte
            // Etape 2 : on transmet les commandes
            // Etape 3 : on aspire le catalogue
            // Etape 4 : on aspire les stocks et les prix
        }
        catch (Exception $e)
        {
            // Journalisation de l'erreur
            \PrestaShopLogger::addLog('LCVPrestaConnector : Erreur à la synchronisation : '.$e->getMessage(), 3);
        }
        finally
        {
            // on libère le verrou
            // et si on y arrive pas, on le mentionne dans le journal de Prestashop
            if (!$db->execute('SELECT RELEASE_LOCK(\'' . $lockName . '\')'))
                \PrestaShopLogger::addLog('LCVPrestaConnector : Impossible de libérer le verrou ' . $lockName, 3);
        }
    }
}